@@ -9,10 +9,9 @@ enum_unitary!{
 }
 
 fn main() {
-  use enum_unitary::{EnumUnitary, Bounded, FromPrimitive, ToPrimitive};
+  use enum_unitary::{FromPrimitive, ToPrimitive};
 
-  assert_eq!(Myenum::count(), 3);
-  assert_eq!(Myenum::count_variants(), 3);
+  assert_eq!(enum_iterator::cardinality::<Myenum>(), 3);
   assert_eq!(Into::<usize>::into (Myenum::A), 0);
   assert_eq!(Into::<usize>::into (Myenum::B), 1);
   assert_eq!(Into::<usize>::into (Myenum::C), 2);
@@ -23,17 +22,17 @@ fn main() {
   assert_eq!(Some (0), Myenum::A.to_usize());
   assert_eq!(Some (1), Myenum::B.to_usize());
   assert_eq!(Some (2), Myenum::C.to_usize());
-  assert_eq!(Myenum::min_value(), Myenum::A);
-  assert_eq!(Myenum::max_value(), Myenum::C);
-  let mut i = Myenum::iter_variants();
+  assert_eq!(enum_iterator::first::<Myenum>().unwrap(), Myenum::A);
+  assert_eq!(enum_iterator::last::<Myenum>().unwrap(),  Myenum::C);
+  let mut i = enum_iterator::all::<Myenum>();
   assert_eq!(i.next(), Some (Myenum::A));
   assert_eq!(i.next(), Some (Myenum::B));
   assert_eq!(i.next(), Some (Myenum::C));
   assert_eq!(i.next(), None);
-  assert_eq!(Myenum::A.next_variant(), Some (Myenum::B));
-  assert_eq!(Myenum::A.prev_variant(), None);
-  assert_eq!(Myenum::B.next_variant(), Some (Myenum::C));
-  assert_eq!(Myenum::B.prev_variant(), Some (Myenum::A));
-  assert_eq!(Myenum::C.next_variant(), None);
-  assert_eq!(Myenum::C.prev_variant(), Some (Myenum::B));
+  assert_eq!(enum_iterator::next (&Myenum::A), Some (Myenum::B));
+  assert_eq!(enum_iterator::previous (&Myenum::A), None);
+  assert_eq!(enum_iterator::next (&Myenum::B), Some (Myenum::C));
+  assert_eq!(enum_iterator::previous (&Myenum::B), Some (Myenum::A));
+  assert_eq!(enum_iterator::next (&Myenum::C), None);
+  assert_eq!(enum_iterator::previous (&Myenum::C), Some (Myenum::B));
 }
